using UnityEngine;
using System.Collections;


[RequireComponent( typeof( GUIText ) )]
public class FPSHUD : MonoBehaviour 
{

	// Attach this to a GUIText to make a frames/second indicator.
	//
	// It calculates frames/second over each updateInterval,
	// so the display does not keep changing wildly.
	//
	// It is also fairly accurate at very low FPS counts (<10).
	// We do this not by simply counting frames per interval, but
	// by accumulating FPS for each frame. This way we end up with
	// correct overall FPS even if the interval renders something like
	// 5.5 frames.
 
	public  float updateInterval = 0.5f;
 
	private float accum   = 0; // FPS accumulated over the interval
	private int   frames  = 0; // Frames drawn over the interval
	private float timeleft; // Left time for current interval


	public bool isRounded_boolean = false;

	//
	public Color defaultFontColor = Color.green;

	void Awake()
	{
		Application.targetFrameRate = 60;
		useGUILayout = false;
	}


	void Start()
	{
	    if( !guiText )
	    {
	        Debug.Log("UtilityFramesPerSecond needs a GUIText component!");
	        enabled = false;
	        return;
	    }
	    timeleft = updateInterval;  
	}


	void Update()
	{
	    timeleft -= Time.deltaTime;
	    accum += Time.timeScale/Time.deltaTime;
	    ++frames;
    
	    // Interval ended - update GUI text and start new interval
	    if( timeleft <= 0.0 )
	    {
	        // display two fractional digits (f2 format)
		    float fps = accum/frames;
			string format;
			if (isRounded_boolean) {
				fps = Mathf.RoundToInt (fps);
				format = System.String.Format("{0} FPS", fps);
			} else {

				format = System.String.Format("{0:F2} FPS", fps);

			}
		    guiText.text = format;

		    if( fps < 20 )
			{
		        guiText.material.color = Color.yellow;
			}
		    else 
			{
		        if( fps < 10 )
		            guiText.material.color = Color.red;
		        else
					guiText.material.color = defaultFontColor;
	
		        timeleft = updateInterval;
		        accum = 0.0F;
		        frames = 0;
		    }
		}
	}

}